%bcond_without     eddsa
%bcond_with     gost
%global pkgname %{name}-%{version}

%{?filter_setup:
%global _ldns_internal_filter /^_ldns[.]so.*/d;
%filter_from_requires %{_ldns_internal_filter}
%filter_from_provides %{_ldns_internal_filter}
%filter_setup
}
%global _ldns_internal _ldns[.]so[.].*
%global __requires_exclude ^(%{_ldns_internal})$
%global __provides_exclude ^(%{_ldns_internal})$

%{?perl_default_filter}

Summary:       Low-level DNS(SEC) library with API
Name:          ldns
Version:       1.8.3
Release:       6%{?dist}
License:       BSD-3-Clause
Url:           https://www.nlnetlabs.nl/%{name}/
Source0:       https://www.nlnetlabs.nl/downloads/%{name}/%{name}-%{version}.tar.gz

Patch3000:     ldns-1.7.0-multilib.patch

BuildRequires: gcc make libpcap-devel openssl-devel gcc-c++ doxygen gnupg2
BuildRequires: python3-devel swig perl-devel perl-ExtUtils-MakeMaker
BuildRequires: perl-generators perl(Devel::CheckLib) perl-interpreter
Requires:      ca-certificates

%description
ldns is a library with the aim to simplify DNS programming in C. All low-level DNS/DNSSEC
operations are supported. We also define a higher level API which allows a programmer to
(for instance) create or sign packets.

%package devel
Summary: Development package that includes the ldns header files
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig openssl-devel
Provides: %{name}-doc = %{version}-%{release}
Obsoletes: %{name}-doc <= %{version}-%{release}

%description devel
The devel package contains the ldns library and the include files
This package also contains documentation for the ldns library

%package utils
Summary: DNS(SEC) utilities for querying dns
Requires: %{name} = %{version}-%{release}

%description utils
Collection of tools to get, check or alter DNS(SEC) data.

%package -n python3-ldns
Summary: Python3 extensions for ldns
Requires: %{name} = %{version}-%{release}

%description -n python3-ldns
Python3 extensions for ldns

%package -n perl-ldns
Summary: Perl extensions for ldns
Requires: %{name} = %{version}-%{release}
Requires:  perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description -n perl-ldns
Perl extensions for ldns

%prep
%autosetup -cn %{pkgname} -N
pushd %{pkgname}

%autopatch -p2
sed -i "s/@includedir@/@includedir@\/ldns/" packaging/libldns.pc.in
cp -pr doc LICENSE README* Changelog ../
cp -p contrib/ldnsx/LICENSE ../LICENSE.ldnsx
cp -p contrib/ldnsx/README ../README.ldnsx
popd

cp -a %{pkgname} %{pkgname}_python3

%build
CFLAGS="%{optflags} -fPIC -fno-strict-aliasing"
CXXFLAGS="%{optflags} -fPIC -fno-strict-aliasing"
LDFLAGS="$RPM_LD_FLAGS -Wl,-z,now -pie"
export CFLAGS CXXFLAGS LDFLAGS

%if %{with gost}
  %global enable_gost --enable-gost
%else
  %global enable_gost --disable-gost
%endif

%if %{with eddsa}
  %global enable_eddsa --enable-ed25519 --enable-ed448
%else
  %global enable_eddsa --disable-ed25519 --disable-ed448
%endif

%global common_args \\\
  --disable-rpath \\\
  %{enable_gost} %{enable_eddsa} --enable-ecdsa --disable-dane-ta-usage \\\
  --with-ca-file=/etc/pki/tls/certs/ca-bundle.trust.crt \\\
  --with-ca-path=/etc/pki/tls/certs/ \\\
  --with-trust-anchor=%{_sharedstatedir}/unbound/root.key \\\
  --disable-static \\\

pushd %{pkgname}_python3

%configure \
  %{common_args} \
  --with-examples \
  --with-drill \
  --with-pyldns PYTHON=%{__python3}

make
%make_build doc

sed -e "s,-L%{_libdir},," -i packaging/ldns-config

pushd contrib/DNS-LDNS
LD_LIBRARY_PATH="../../lib:$LD_LIBRARY_PATH" perl \
    Makefile.PL INSTALLDIRS=vendor  INC="-I. -I../.." LIBS="-L../../lib"
%make_build -j1
popd

sed -i "s~$RPM_LD_FLAGS~~" packaging/ldns-config
popd

%install
rm -rf %{buildroot}

pushd %{pkgname}_python3
mkdir -p %{buildroot}%{_libdir}/pkgconfig
%make_install install
%make_install install-doc

rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{python3_sitearch}/*.la

%make_install -j1 -C contrib/DNS-LDNS pure_install
chmod 755 %{buildroot}%{perl_vendorarch}/auto/DNS/LDNS/LDNS.so
rm -f %{buildroot}%{perl_vendorarch}/auto/DNS/LDNS/{.packlist,LDNS.bs}
rm -f %{buildroot}%{perl_archlib}/perllocal.pod
popd

rm doc/*.xml
rm doc/doxyparse.pl
rm -rf doc/man

%files
%license LICENSE
%doc README
%{_libdir}/libldns.so.3*

%files utils
%{_bindir}/drill
%{_bindir}/ldnsd
%{_bindir}/ldns-chaos
%{_bindir}/ldns-compare-zones
%{_bindir}/ldns-[d-z]*
%{_mandir}/man1/*

%files devel
%doc Changelog README.git
%doc doc
%{_libdir}/libldns.so
%{_libdir}/pkgconfig/ldns.pc
%{_bindir}/ldns-config
%dir %{_includedir}/ldns
%{_includedir}/ldns/*.h
%{_mandir}/man3/*.3.gz

%files -n python3-ldns
%license LICENSE.ldnsx
%doc %{pkgname}_python3/contrib/python/Changelog README.ldnsx
%{python3_sitearch}/*

%files -n perl-ldns
%{perl_vendorarch}/*
%exclude %dir %{perl_vendorarch}/auto/
%{_mandir}/man3/*.3pm.gz

%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.3-6
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.3-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.3-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.3-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 23 2023 Miaojun Dong <zoedong@tencent.com> - 1.8.3-2
- enable eddsa to enable ed25519 and ed448

* Wed Nov 30 2022 Shuo Wang <abushwang@tencent.com> - 1.8.3-1
- initial build

